@@ -15,9 +15,9 @@ class Accountant:
     """
     DEFAULT_CASH_BOOK_ID = {'name': 'cash_book', 'id': '1'}
 
-    def __init__(self, bank_account, ledger_host):
+    def __init__(self, bank_account, ledger_host, ledger_read_host=None):
         self.bank_account = bank_account
-        self.ledger = LedgerClient(ledger_host=ledger_host)
+        self.ledger = LedgerClient(ledger_endpoint=ledger_host, ledger_read_only_endpoint=ledger_read_host)
 
         log.info("---------Initialising-------------")
         log.info(f"Bank Account Number:  {self.bank_account['account_id']}")
@@ -149,7 +149,7 @@ class Accountant:
     @staticmethod
     def create_book(account_id: str, ledger_host):
         log.info("---------New_ledger-------------")
-        ledger = LedgerClient(ledger_host=ledger_host)
+        ledger = LedgerClient(ledger_endpoint=ledger_host)
         block_book_id = ledger.create_book(name=f"{account_id}_block_book", min_balance="0")
         main_book_id = ledger.create_book(name=f"{account_id}_main_book", min_balance="0")
         new_books = {
@@ -159,4 +159,4 @@ class Accountant:
                                 'id': block_book_id['id']}
         }
         log.info(new_books)
-        return new_books
+        return new_books
\ No newline at end of file
