@@ -24,12 +24,17 @@ class OperationStatus(AutoName):
 
 
 class LedgerClient:
-    def __init__(self, ledger_host: str):
-        self.rpc_client = HTTPClient(ledger_host)
+    def __init__(self, ledger_endpoint: str, ledger_read_only_endpoint: str = None):
+        self.rpc_client = HTTPClient(ledger_endpoint)
+        if ledger_read_only_endpoint is not None:
+            self.read_only_rpc_client = HTTPClient(ledger_read_only_endpoint)
 
-    def _execute(self, method: str, *args):
+    def _execute(self, method: str, *args, read_only_method: bool = False):
         start_time = int(time.time()*1000)
-        rpc_response = self.rpc_client.request(method, *args)
+        if read_only_method is True and self.read_only_rpc_client:
+            rpc_response = self.read_only_rpc_client.request(method, *args)
+        else:
+            rpc_response = self.rpc_client.request(method, *args)
         end_time = int(time.time()*1000)
         log.info(f"LedgerClient: {method}: time_taken: {end_time-start_time}ms")
         return rpc_response.data.result
@@ -44,16 +49,16 @@ class LedgerClient:
         return self._execute("createBook", book_info)
 
     def get_book(self, book_id: str):
-        return self._execute("getBook", book_id)
+        return self._execute("getBook", book_id, read_only_method=True)
 
     def get_book_balances(self, book_id: str, asset_id: str = None, metadata_filter: dict = None):
-        return self._execute("getBalances", book_id, asset_id, metadata_filter)
+        return self._execute("getBalances", book_id, asset_id, metadata_filter, read_only_method=True)
 
     def get_operation(self, operation_id: str):
-        return self._execute("getOperation", operation_id)
+        return self._execute("getOperation", operation_id, read_only_method=True)
 
     def get_operations(self, book_id: str, metadata_filter: dict = None):
-        return self._execute("getOperations", book_id, metadata_filter)
+        return self._execute("getOperations", book_id, metadata_filter, read_only_method=True)
 
     def post_operation(self, operation_type: OperationType, entries: List[dict], memo: str = "", metadata: dict = None, sync: bool = False):
         operation = dict()
